import { Component, createSignal, For, JSX } from 'solid-js';

import styles from './Dialog.module.css';
import DialogButtonComponent from './DialogButtonComponent';

export interface DialogButton {
	name: string,
	action?: () => void | boolean | Promise<void> | Promise<boolean>,
	type?: 'default' | 'danger' | 'success'
}

export interface DialogInputField {
	name: string,
	placeholder?: string,
	onInput: (text: string) => void,
}

export interface DialogProps {
	title: string,
	text?: string,
	buttons?: (string | DialogButton)[],
	onDismiss?: () => void,
	inputFields?: DialogInputField[],
	content?: JSX.Element,
}

function createInputField(field: DialogInputField) {
	return <div class={styles.dialogInput}>
		<span>{field.name}</span>
		<input placeholder={field.placeholder ?? field.name} onInput={e => field.onInput(e.currentTarget.value)}></input>
	</div>;
}

const Dialog: Component<DialogProps> = props => {
	const buttons: () => (string | DialogButton)[] = () => props.buttons == null ? ["Okay"] : props.buttons;
	const [loading, setLoading] = createSignal(false);

	return (
		<div class={styles.dialogContainer}>
			<div class={styles.dialog}>
				<div class={styles.dialogTitle}>{props.title}</div>
				<div class={styles.dialogText}>{props.text}</div>
				{props.inputFields && props.inputFields.length > 0 && <div class={styles.dialogInputFields}>
					<For each={props.inputFields}>{f => createInputField(f)}</For>
				</div>}
				{props.content}
				<div class={styles.dialogButtons}>
					<For each={buttons()}>{b => //createButton(b, props.onDismiss);
						<DialogButtonComponent button={b} dismiss={props.onDismiss} loading={loading()} setLoading={setLoading} />
					}
					</For>
				</div>
			</div>
		</div>
	);
};

export default Dialog;
