import { Component } from "solid-js";
import { DialogButton } from "./Dialog";
import styles from './Dialog.module.css';

export interface DialogButtonProps {
    dismiss?: () => void
    button: string | DialogButton
    loading: boolean
    setLoading: (b: boolean) => void
}

const DialogButtonComponent: Component<DialogButtonProps> = (props) => {
    if (typeof props.button == 'string') {
        return <button onclick={props.dismiss} class={styles.defaultButton}>{props.button}</button>;
    } else {
        const clickHandler = () => {
            props.setLoading(true);
            Promise.resolve((props.button as DialogButton).action?.()).then(v => {
                if (v === undefined || v === true) props.dismiss?.();
                props.setLoading(false);
            });
        };
        return <button disabled={props.loading} onclick={clickHandler} class={styles[props.button.type + 'Button']}>{props.button.name}</button>;
    }
}

export default DialogButtonComponent;
