import styles from './StratItem.module.css';
import { Component } from "solid-js";
import { Group, Strat, api } from "../api";
import { showDialog, showMessageDialog } from "../state";
import { errorToString } from "../util";
import { BsTrash } from 'solid-icons/bs';
import { useNavigate } from '@solidjs/router';

export interface StratItemProps {
	group: Group,
	strat: Strat,
	onDelete: (m: Strat) => void
}

const StratItem: Component<StratItemProps> = (props) => {
	const navigate = useNavigate();

	const deleteMember = async () => {
		showDialog({
			title: 'Remove strat',
			text: 'Do you want to remove this strat?',
			buttons: [
				{
					name: 'Remove',
					type: 'danger',
					action: async () => {
						try {
							await api().removeStrat(props.group.id, props.strat.id);
							props.onDelete(props.strat);
						} catch (e) {
							showMessageDialog('Failed to remove strat', errorToString(e));
						}
					}
				},
				{
					name: 'Cancel',
					action: () => { }
				}
			]
		});
	};

	return (
		<div class={styles.member}>
			<div class={styles.memberDetails}>
				<div class={styles.memberName} onclick={() => navigate('/group/' + props.group.id + '/strat/' + props.strat.id)}>
					<span innerText={props.strat.title} />
					<span innerText={props.strat.description} />
					<span innerText={props.strat.stratType} />
				</div>
				<div>
					<button onClick={deleteMember}><BsTrash /></button>
				</div>
			</div>
		</div >
	)
}

export default StratItem;
